@@ -25,7 +25,6 @@ from . import stats
 from . import truncate
 from . import utils
 from . import utils_geo
-from . import utils_graph
 from ._errors import CacheOnlyInterruptError
 from ._errors import InsufficientResponseError
 from ._version import __version__
@@ -37,7 +36,7 @@ def graph_from_bbox(
     east=None,
     west=None,
     bbox=None,
-    network_type="all_private",
+    network_type="all",
     simplify=True,
     retain_all=False,
     truncate_by_edge=False,
@@ -63,7 +62,7 @@ def graph_from_bbox(
         deprecated, do not use
     bbox : tuple of floats
         bounding box as (north, south, east, west)
-    network_type : string {"all_private", "all", "bike", "drive", "drive_service", "walk"}
+    network_type : string {"all", "all_public", "bike", "drive", "drive_service", "walk"}
         what type of street network to get if custom_filter is None
     simplify : bool
         if True, simplify graph topology with the `simplify_graph` function
@@ -94,7 +93,8 @@ def graph_from_bbox(
     if not (north is None and south is None and east is None and west is None):
         msg = (
             "The `north`, `south`, `east`, and `west` parameters are deprecated and "
-            "will be removed in the v2.0.0 release. Use the `bbox` parameter instead."
+            "will be removed in the v2.0.0 release. Use the `bbox` parameter instead. "
+            "See the OSMnx v2 migration guide: https://github.com/gboeing/osmnx/issues/1123"
         )
         warn(msg, FutureWarning, stacklevel=2)
         bbox = (north, south, east, west)
@@ -121,7 +121,7 @@ def graph_from_point(
     center_point,
     dist=1000,
     dist_type="bbox",
-    network_type="all_private",
+    network_type="all",
     simplify=True,
     retain_all=False,
     truncate_by_edge=False,
@@ -146,7 +146,7 @@ def graph_from_point(
         if "bbox", retain only those nodes within a bounding box of the
         distance parameter. if "network", retain only those nodes within some
         network distance from the center-most node.
-    network_type : string, {"all_private", "all", "bike", "drive", "drive_service", "walk"}
+    network_type : string, {"all", "all_public", "bike", "drive", "drive_service", "walk"}
         what type of street network to get if custom_filter is None
     simplify : bool
         if True, simplify graph topology with the `simplify_graph` function
@@ -206,7 +206,7 @@ def graph_from_address(
     address,
     dist=1000,
     dist_type="bbox",
-    network_type="all_private",
+    network_type="all",
     simplify=True,
     retain_all=False,
     truncate_by_edge=False,
@@ -233,7 +233,7 @@ def graph_from_address(
         if "bbox", retain only those nodes within a bounding box of the
         distance parameter. if "network", retain only those nodes within some
         network distance from the center-most node.
-    network_type : string {"all_private", "all", "bike", "drive", "drive_service", "walk"}
+    network_type : string {"all", "all_public", "bike", "drive", "drive_service", "walk"}
         what type of street network to get if custom_filter is None
     simplify : bool
         if True, simplify graph topology with the `simplify_graph` function
@@ -269,7 +269,8 @@ def graph_from_address(
         warn(
             "The `return_coords` argument has been deprecated and will be removed in "
             "the v2.0.0 release. Future behavior will be as though `return_coords=False`. "
-            "If you want the address's geocoded coordinates, use the `geocode` function.",
+            "If you want the address's geocoded coordinates, use the `geocode` function. "
+            "See the OSMnx v2 migration guide: https://github.com/gboeing/osmnx/issues/1123",
             FutureWarning,
             stacklevel=2,
         )
@@ -299,7 +300,7 @@ def graph_from_address(
 
 def graph_from_place(
     query,
-    network_type="all_private",
+    network_type="all",
     simplify=True,
     retain_all=False,
     truncate_by_edge=False,
@@ -331,7 +332,7 @@ def graph_from_place(
     ----------
     query : string or dict or list
         the query or queries to geocode to get place boundary polygon(s)
-    network_type : string {"all_private", "all", "bike", "drive", "drive_service", "walk"}
+    network_type : string {"all", "all_public", "bike", "drive", "drive_service", "walk"}
         what type of street network to get if custom_filter is None
     simplify : bool
         if True, simplify graph topology with the `simplify_graph` function
@@ -367,7 +368,8 @@ def graph_from_place(
     if buffer_dist is not None:
         warn(
             "The buffer_dist argument has been deprecated and will be removed "
-            "in the v2.0.0 release. Buffer your query area directly, if desired.",
+            "in the v2.0.0 release. Buffer your query area directly, if desired. "
+            "See the OSMnx v2 migration guide: https://github.com/gboeing/osmnx/issues/1123",
             FutureWarning,
             stacklevel=2,
         )
@@ -407,7 +409,7 @@ def graph_from_place(
 
 def graph_from_polygon(
     polygon,
-    network_type="all_private",
+    network_type="all",
     simplify=True,
     retain_all=False,
     truncate_by_edge=False,
@@ -426,7 +428,7 @@ def graph_from_polygon(
     polygon : shapely.geometry.Polygon or shapely.geometry.MultiPolygon
         the shape to get network data within. coordinates should be in
         unprojected latitude-longitude degrees (EPSG:4326).
-    network_type : string {"all_private", "all", "bike", "drive", "drive_service", "walk"}
+    network_type : string {"all", "all_public", "bike", "drive", "drive_service", "walk"}
         what type of street network to get if custom_filter is None
     simplify : bool
         if True, simplify graph topology with the `simplify_graph` function
@@ -459,7 +461,8 @@ def graph_from_polygon(
     else:
         warn(
             "The clean_periphery argument has been deprecated and will be removed in "
-            "the v2.0.0 release. Future behavior will be as though clean_periphery=True.",
+            "the v2.0.0 release. Future behavior will be as though clean_periphery=True. "
+            "See the OSMnx v2 migration guide: https://github.com/gboeing/osmnx/issues/1123",
             FutureWarning,
             stacklevel=2,
         )
@@ -658,7 +661,7 @@ def _create_graph(response_jsons, retain_all=False, bidirectional=False):
 
     # retain only the largest connected component if retain_all=False
     if not retain_all:
-        G = utils_graph.get_largest_component(G)
+        G = truncate.largest_component(G)
 
     utils.log(f"Created graph with {len(G):,} nodes and {len(G.edges):,} edges")
 
