@@ -1,6 +1,7 @@
 """Simplify, correct, and consolidate network topology."""
 
 import logging as lg
+from warnings import warn
 
 import geopandas as gpd
 import networkx as nx
@@ -9,23 +10,31 @@ from shapely.geometry import MultiPolygon
 from shapely.geometry import Point
 from shapely.geometry import Polygon
 
+from . import convert
 from . import stats
 from . import utils
-from . import utils_graph
+from ._errors import GraphSimplificationError
 
 
-def _is_endpoint(G, node, strict=True):
+def _is_endpoint(G, node, endpoint_attrs):
     """
-    Is node a true endpoint of an edge.
+    Determine if a node is a true endpoint of an edge.
 
-    Return True if the node is a "real" endpoint of an edge in the network,
-    otherwise False. OSM data includes lots of nodes that exist only as points
-    to help streets bend around curves. An end point is a node that either:
-    1) is its own neighbor, ie, it self-loops.
-    2) or, has no incoming edges or no outgoing edges, ie, all its incident
-    edges point inward or all its incident edges point outward.
-    3) or, it does not have exactly two neighbors and degree of 2 or 4.
-    4) or, if strict mode is false, if its edges have different OSM IDs.
+    Return True if the node is a "true" endpoint of an edge in the network,
+    otherwise False. OpenStreetMap data includes many nodes that exist only as
+    geometric vertices to allow ways to curve. A true edge endpoint is a node
+    that satisfies at least 1 of the following 4 rules:
+
+    1) It is its own neighbor (ie, it self-loops).
+
+    2) Or, it has no incoming edges or no outgoing edges (ie, all its incident
+    edges are inbound or all its incident edges are outbound).
+
+    3) Or, it does not have exactly two neighbors and degree of 2 or 4.
+
+    4) Or, if `endpoint_attrs` is not None, and its incident edges have
+    different values than each other for any of the edge attributes in
+    `endpoint_attrs`.
 
     Parameters
     ----------
@@ -33,9 +42,11 @@ def _is_endpoint(G, node, strict=True):
         input graph
     node : int
         the node to examine
-    strict : bool
-        if False, allow nodes to be end points even if they fail all other rules
-        but have edges with different OSM IDs
+    endpoint_attrs : iterable
+        An iterable of edge attribute names for relaxing the strictness of
+        endpoint determination. If not None, a node is an endpoint if its
+        incident edges have different values then each other for any of the
+        edge attributes in `endpoint_attrs`.
 
     Returns
     -------
@@ -45,49 +56,40 @@ def _is_endpoint(G, node, strict=True):
     n = len(neighbors)
     d = G.degree(node)
 
-    # rule 1
+    # RULE 1
+    # if the node appears in its list of neighbors, it self-loops: this is
+    # always an endpoint
     if node in neighbors:
-        # if the node appears in its list of neighbors, it self-loops
-        # this is always an endpoint.
         return True
 
-    # rule 2
-    elif G.out_degree(node) == 0 or G.in_degree(node) == 0:
-        # if node has no incoming edges or no outgoing edges, it is an endpoint
+    # RULE 2
+    # if node has no incoming edges or no outgoing edges, it is an endpoint
+    if G.out_degree(node) == 0 or G.in_degree(node) == 0:
         return True
 
-    # rule 3
-    elif not (n == 2 and (d == 2 or d == 4)):
-        # else, if it does NOT have 2 neighbors AND either 2 or 4 directed
-        # edges, it is an endpoint. either it has 1 or 3+ neighbors, in which
-        # case it is a dead-end or an intersection of multiple streets or it has
-        # 2 neighbors but 3 degree (indicating a change from oneway to twoway)
-        # or more than 4 degree (indicating a parallel edge) and thus is an
-        # endpoint
+    # RULE 3
+    # else, if it does NOT have 2 neighbors AND either 2 or 4 directed edges,
+    # it is an endpoint. either it has 1 or 3+ neighbors, in which case it is
+    # a dead-end or an intersection of multiple streets or it has 2 neighbors
+    # but 3 degree (indicating a change from oneway to twoway) or more than 4
+    # degree (indicating a parallel edge) and thus is an endpoint
+    if not ((n == 2) and (d in {2, 4})):  # noqa: PLR2004
         return True
 
-    # rule 4
-    elif not strict:
-        # non-strict mode: do its incident edges have different OSM IDs?
-        osmids = []
+    # RULE 4
+    # non-strict mode: do its incident edges have different attr values? for
+    # each attribute to check, collect the attribute's values in all inbound
+    # and outbound edges. if there is more than 1 unique value then then this
+    # node is an endpoint
+    if endpoint_attrs is not None:
+        for attr in endpoint_attrs:
+            in_values = {v for _, _, v in G.in_edges(node, data=attr, keys=False)}
+            out_values = {v for _, _, v in G.out_edges(node, data=attr, keys=False)}
+            if len(in_values | out_values) > 1:
+                return True
 
-        # add all the edge OSM IDs for incoming edges
-        for u in G.predecessors(node):
-            for key in G[u][node]:
-                osmids.append(G.edges[u, node, key]["osmid"])
-
-        # add all the edge OSM IDs for outgoing edges
-        for v in G.successors(node):
-            for key in G[node][v]:
-                osmids.append(G.edges[node, v, key]["osmid"])
-
-        # if there is more than 1 OSM ID in the list of edge OSM IDs then it is
-        # an endpoint, if not, it isn't
-        return len(set(osmids)) > 1
-
-    # if none of the preceding rules returned true, then it is not an endpoint
-    else:
-        return False
+    # if none of the preceding rules passed, then it is not an endpoint
+    return False
 
 
 def _build_path(G, endpoint, endpoint_successor, endpoints):
@@ -117,7 +119,8 @@ def _build_path(G, endpoint, endpoint_successor, endpoints):
     path = [endpoint, endpoint_successor]
 
     # for each successor of the endpoint's successor
-    for successor in G.successors(endpoint_successor):
+    for this_successor in G.successors(endpoint_successor):
+        successor = this_successor
         if successor not in path:
             # if this successor is already in the path, ignore it, otherwise add
             # it to the path
@@ -137,19 +140,19 @@ def _build_path(G, endpoint, endpoint_successor, endpoints):
                         # we have come to the end of a self-looping edge, so
                         # add first node to end of path to close it and return
                         return path + [endpoint]
-                    else:  # pragma: no cover
-                        # this can happen due to OSM digitization error where
-                        # a one-way street turns into a two-way here, but
-                        # duplicate incoming one-way edges are present
-                        utils.log(
-                            f"Unexpected simplify pattern handled near {successor}", level=lg.WARN
-                        )
-                        return path
+
+                    # otherwise, this can happen due to OSM digitization error
+                    # where a one-way street turns into a two-way here, but
+                    # duplicate incoming one-way edges are present
+                    msg = f"Unexpected simplify pattern handled near {successor}"
+                    utils.log(msg, level=lg.WARNING)
+                    return path
                 else:  # pragma: no cover
                     # if successor has >1 successors, then successor must have
                     # been an endpoint because you can go in 2 new directions.
                     # this should never occur in practice
-                    raise Exception(f"Unexpected simplify pattern failed near {successor}")
+                    msg = f"Impossible simplify pattern failed near {successor}"
+                    raise GraphSimplificationError(msg)
 
             # if this successor is an endpoint, we've completed the path
             return path
@@ -159,7 +162,7 @@ def _build_path(G, endpoint, endpoint_successor, endpoints):
     return path
 
 
-def _get_paths_to_simplify(G, strict=True):
+def _get_paths_to_simplify(G, endpoint_attrs):
     """
     Generate all the paths to be simplified between endpoint nodes.
 
@@ -170,17 +173,20 @@ def _get_paths_to_simplify(G, strict=True):
     ----------
     G : networkx.MultiDiGraph
         input graph
-    strict : bool
-        if False, allow nodes to be end points even if they fail all other rules
-        but have edges with different OSM IDs
+    endpoint_attrs : iterable
+        An iterable of edge attribute names for relaxing the strictness of
+        endpoint determination. If not None, a node is an endpoint if its
+        incident edges have different values then each other for any of the
+        edge attributes in `endpoint_attrs`.
 
     Yields
     ------
     path_to_simplify : list
+        a generator of paths to simplify
     """
     # first identify all the nodes that are endpoints
-    endpoints = {n for n in G.nodes if _is_endpoint(G, n, strict=strict)}
-    utils.log(f"Identified {len(endpoints)} edge endpoints")
+    endpoints = {n for n in G.nodes if _is_endpoint(G, n, endpoint_attrs)}
+    utils.log(f"Identified {len(endpoints):,} edge endpoints")
 
     # for each endpoint node, look at each of its successor nodes
     for endpoint in endpoints:
@@ -192,9 +198,9 @@ def _get_paths_to_simplify(G, strict=True):
                 yield _build_path(G, endpoint, successor, endpoints)
 
 
-def _remove_rings(G):
+def _remove_rings(G, endpoint_attrs):
     """
-    Remove self-contained rings from graph.
+    Remove all self-contained rings from a graph.
 
     This identifies any connected components that form a self-contained ring
     without any endpoints, and removes them from the graph.
@@ -203,6 +209,11 @@ def _remove_rings(G):
     ----------
     G : networkx.MultiDiGraph
         input graph
+    endpoint_attrs : iterable
+        An iterable of edge attribute names for relaxing the strictness of
+        endpoint determination. If not None, a node is an endpoint if its
+        incident edges have different values then each other for any of the
+        edge attributes in `endpoint_attrs`.
 
     Returns
     -------
@@ -211,35 +222,54 @@ def _remove_rings(G):
     """
     nodes_in_rings = set()
     for wcc in nx.weakly_connected_components(G):
-        if not any(_is_endpoint(G, n) for n in wcc):
+        if not any(_is_endpoint(G, n, endpoint_attrs) for n in wcc):
             nodes_in_rings.update(wcc)
     G.remove_nodes_from(nodes_in_rings)
     return G
 
 
-def simplify_graph(G, strict=True, remove_rings=True, track_merged=False):
+def simplify_graph(  # noqa: C901
+    G,
+    strict=None,
+    edge_attrs_differ=None,
+    endpoint_attrs=None,
+    remove_rings=True,
+    track_merged=False,
+):
     """
     Simplify a graph's topology by removing interstitial nodes.
 
-    Simplifies graph topology by removing all nodes that are not intersections
-    or dead-ends. Create an edge directly between the end points that
-    encapsulate them, but retain the geometry of the original edges, saved as
-    a new `geometry` attribute on the new edge. Note that only simplified
-    edges receive a `geometry` attribute. Some of the resulting consolidated
-    edges may comprise multiple OSM ways, and if so, their multiple attribute
-    values are stored as a list. Optionally, the simplified edges can receive
-    a `merged_edges` attribute that contains a list of all the (u, v) node
-    pairs that were merged together.
+    This simplifies graph topology by removing all nodes that are not
+    intersections or dead-ends, by creating an edge directly between the end
+    points that encapsulate them while retaining the full geometry of the
+    original edges, saved as a new `geometry` attribute on the new edge.
+
+    Note that only simplified edges receive a `geometry` attribute. Some of
+    the resulting consolidated edges may comprise multiple OSM ways, and if
+    so, their multiple attribute values are stored as a list. Optionally, the
+    simplified edges can receive a `merged_edges` attribute that contains a
+    list of all the (u, v) node pairs that were merged together.
+
+    Use the `edge_attrs_differ` parameter to relax simplification strictness. For
+    example, `edge_attrs_differ=['osmid']` will retain every node whose incident
+    edges have different OSM IDs. This lets you keep nodes at elbow two-way
+    intersections (but be aware that sometimes individual blocks have multiple
+    OSM IDs within them too). You could also use this parameter to retain
+    nodes where sidewalks or bike lanes begin/end in the middle of a block.
 
     Parameters
     ----------
     G : networkx.MultiDiGraph
         input graph
     strict : bool
-        if False, allow nodes to be end points even if they fail all other
-        rules but have incident edges with different OSM IDs. Lets you keep
-        nodes at elbow two-way intersections, but sometimes individual blocks
-        have multiple OSM IDs within them too.
+        deprecated, do not use
+    edge_attrs_differ : iterable
+        An iterable of edge attribute names for relaxing the strictness of
+        endpoint determination. If not None, a node is an endpoint if its
+        incident edges have different values then each other for any of the
+        edge attributes in `edge_attrs_differ`.
+    endpoint_attrs : iterable
+        deprecated, do not use
     remove_rings : bool
         if True, remove isolated self-contained rings that have no endpoints
     track_merged : bool
@@ -252,8 +282,31 @@ def simplify_graph(G, strict=True, remove_rings=True, track_merged=False):
         topologically simplified graph, with a new `geometry` attribute on
         each simplified edge
     """
+    if endpoint_attrs is not None:
+        msg = (
+            "The `endpoint_attrs` parameter has been deprecated and will be removed "
+            "in the v2.0.0 release. Use the `edge_attrs_differ` parameter instead. "
+            "See the OSMnx v2 migration guide: https://github.com/gboeing/osmnx/issues/1123"
+        )
+        warn(msg, FutureWarning, stacklevel=2)
+        edge_attrs_differ = endpoint_attrs
+
+    if strict is not None:
+        msg = (
+            "The `strict` parameter has been deprecated and will be removed in "
+            "the v2.0.0 release. Use the `edge_attrs_differ` parameter instead to "
+            "relax simplification strictness. For example, `edge_attrs_differ=None` "
+            "reproduces the old `strict=True` behvavior and `edge_attrs_differ=['osmid']` "
+            "reproduces the old `strict=False` behavior. "
+            "See the OSMnx v2 migration guide: https://github.com/gboeing/osmnx/issues/1123"
+        )
+        warn(msg, FutureWarning, stacklevel=2)
+        # maintain old behavior if strict is passed during deprecation
+        edge_attrs_differ = None if strict else ["osmid"]
+
     if "simplified" in G.graph and G.graph["simplified"]:  # pragma: no cover
-        raise Exception("This graph has already been simplified, cannot simplify it again.")
+        msg = "This graph has already been simplified, cannot simplify it again."
+        raise GraphSimplificationError(msg)
 
     utils.log("Begin topologically simplifying the graph...")
 
@@ -268,7 +321,7 @@ def simplify_graph(G, strict=True, remove_rings=True, track_merged=False):
     all_edges_to_add = []
 
     # generate each path that needs to be simplified
-    for path in _get_paths_to_simplify(G, strict=strict):
+    for path in _get_paths_to_simplify(G, edge_attrs_differ):
         # add the interstitial edges we're removing to a list so we can retain
         # their spatial geometry
         merged_edges = []
@@ -338,14 +391,14 @@ def simplify_graph(G, strict=True, remove_rings=True, track_merged=False):
     G.remove_nodes_from(set(all_nodes_to_remove))
 
     if remove_rings:
-        G = _remove_rings(G)
+        G = _remove_rings(G, edge_attrs_differ)
 
-    # mark graph as having been simplified
+    # mark the graph as having been simplified
     G.graph["simplified"] = True
 
     msg = (
-        f"Simplified graph: {initial_node_count} to {len(G)} nodes, "
-        f"{initial_edge_count} to {len(G.edges)} edges"
+        f"Simplified graph: {initial_node_count:,} to {len(G):,} nodes, "
+        f"{initial_edge_count:,} to {len(G.edges):,} edges"
     )
     utils.log(msg)
     return G
@@ -426,16 +479,17 @@ def consolidate_intersections(
         if not G or not G.edges:
             # cannot rebuild a graph with no nodes or no edges, just return it
             return G
-        else:
-            return _consolidate_intersections_rebuild_graph(G, tolerance, reconnect_edges)
 
-    else:
-        if not G:
-            # if graph has no nodes, just return empty GeoSeries
-            return gpd.GeoSeries(crs=G.graph["crs"])
-        else:
-            # return the centroids of the merged intersection polygons
-            return _merge_nodes_geometric(G, tolerance).centroid
+        # otherwise
+        return _consolidate_intersections_rebuild_graph(G, tolerance, reconnect_edges)
+
+    # otherwise, if we're not rebuilding the graph
+    if not G:
+        # if graph has no nodes, just return empty GeoSeries
+        return gpd.GeoSeries(crs=G.graph["crs"])
+
+    # otherwise, return the centroids of the merged intersection polygons
+    return _merge_nodes_geometric(G, tolerance).centroid
 
 
 def _merge_nodes_geometric(G, tolerance):
@@ -456,11 +510,10 @@ def _merge_nodes_geometric(G, tolerance):
         the merged overlapping polygons of the buffered nodes
     """
     # buffer nodes GeoSeries then get unary union to merge overlaps
-    merged = utils_graph.graph_to_gdfs(G, edges=False)["geometry"].buffer(tolerance).unary_union
+    merged = convert.graph_to_gdfs(G, edges=False)["geometry"].buffer(tolerance).unary_union
 
     # if only a single node results, make it iterable to convert to GeoSeries
     merged = MultiPolygon([merged]) if isinstance(merged, Polygon) else merged
-
     return gpd.GeoSeries(merged.geoms, crs=G.graph["crs"])
 
 
@@ -511,10 +564,11 @@ def _consolidate_intersections_rebuild_graph(G, tolerance=10, reconnect_edges=Tr
     # STEP 2
     # attach each node to its cluster of merged nodes. first get the original
     # graph's node points then spatial join to give each node the label of
-    # cluster it's within
-    node_points = utils_graph.graph_to_gdfs(G, edges=False)[["geometry"]]
+    # cluster it's within. make cluster labels type string.
+    node_points = convert.graph_to_gdfs(G, edges=False)[["geometry"]]
     gdf = gpd.sjoin(node_points, node_clusters, how="left", predicate="within")
     gdf = gdf.drop(columns="geometry").rename(columns={"index_right": "cluster"})
+    gdf["cluster"] = gdf["cluster"].astype(str)
 
     # STEP 3
     # if a cluster contains multiple components (i.e., it's not connected)
@@ -528,8 +582,7 @@ def _consolidate_intersections_rebuild_graph(G, tolerance=10, reconnect_edges=Tr
             wccs = list(nx.weakly_connected_components(G.subgraph(nodes_subset.index)))
             if len(wccs) > 1:
                 # if there are multiple components in this cluster
-                suffix = 0
-                for wcc in wccs:
+                for suffix, wcc in enumerate(wccs):
                     # set subcluster xy to the centroid of just these nodes
                     idx = list(wcc)
                     subcluster_centroid = node_points.loc[idx].unary_union.centroid
@@ -537,7 +590,6 @@ def _consolidate_intersections_rebuild_graph(G, tolerance=10, reconnect_edges=Tr
                     gdf.loc[idx, "y"] = subcluster_centroid.y
                     # move to subcluster by appending suffix to cluster label
                     gdf.loc[idx, "cluster"] = f"{cluster_label}-{suffix}"
-                    suffix += 1
 
     # give nodes unique integer IDs (subclusters with suffixes are strings)
     gdf["cluster"] = gdf["cluster"].factorize()[0]
@@ -579,7 +631,7 @@ def _consolidate_intersections_rebuild_graph(G, tolerance=10, reconnect_edges=Tr
 
     # STEP 6
     # create new edge from cluster to cluster for each edge in original graph
-    gdf_edges = utils_graph.graph_to_gdfs(G, nodes=False)
+    gdf_edges = convert.graph_to_gdfs(G, nodes=False)
     for u, v, k, data in G.edges(keys=True, data=True):
         u2 = gdf.loc[u, "cluster"]
         v2 = gdf.loc[v, "cluster"]
