@@ -4,65 +4,73 @@ import datetime as dt
 import logging as lg
 import os
 import sys
-import unicodedata
-import warnings
+import unicodedata as ud
 from contextlib import redirect_stdout
 from pathlib import Path
+from warnings import warn
 
 from . import settings
 
 
-def citation():
+def citation(style="bibtex"):
     """
     Print the OSMnx package's citation information.
 
-    Boeing, G. 2017. OSMnx: New Methods for Acquiring, Constructing, Analyzing,
-    and Visualizing Complex Street Networks. Computers, Environment and Urban
-    Systems, 65, 126-139. https://doi.org/10.1016/j.compenvurbsys.2017.05.004
+    Boeing, G. (2024). Modeling and Analyzing Urban Networks and Amenities with
+    OSMnx. Working paper. https://geoffboeing.com/publications/osmnx-paper/
+
+    Parameters
+    ----------
+    style : string {"apa", "bibtex", "ieee"}
+        citation format, either APA or BibTeX or IEEE
 
     Returns
     -------
     None
     """
-    cite = (
-        "Citation:\n\n"
-        "Boeing, G. 2017. OSMnx: New Methods for Acquiring, "
-        "Constructing, Analyzing, and Visualizing Complex Street "
-        "Networks. Computers, Environment and Urban Systems, 65, 126-139. "
-        "https://doi.org/10.1016/j.compenvurbsys.2017.05.004\n\n"
-        "BibTeX entry for LaTeX users:\n\n"
-        "@article{boeing_osmnx_2017,\n"
-        "    title = {{OSMnx}: {New} {Methods} for {Acquiring}, "
-        "{Constructing}, {Analyzing}, and {Visualizing} {Complex} "
-        "{Street} {Networks}},\n"
-        "    volume = {65},\n"
-        "    doi = {10.1016/j.compenvurbsys.2017.05.004},\n"
-        "    number = {126-139},\n"
-        "    journal = {Computers, Environment and Urban Systems},\n"
-        "    author = {Boeing, Geoff},\n"
-        "    year = {2017}\n"
-        "}"
-    )
+    if style == "apa":
+        msg = (
+            "Boeing, G. (2024). Modeling and Analyzing Urban Networks and Amenities "
+            "with OSMnx. Working paper. https://geoffboeing.com/publications/osmnx-paper/"
+        )
+    elif style == "bibtex":
+        msg = (
+            "@techreport{boeing_osmnx_2024,\n"
+            "    author = {Boeing, Geoff},\n"
+            "    title = {{Modeling and Analyzing Urban Networks and Amenities with OSMnx}},\n"
+            "    type = {Working paper},\n"
+            "    url = {https://geoffboeing.com/publications/osmnx-paper/},\n"
+            "    year = {2024}\n"
+            "}"
+        )
+    elif style == "ieee":
+        msg = (
+            'G. Boeing, "Modeling and Analyzing Urban Networks and Amenities with OSMnx," '
+            "Working paper, https://geoffboeing.com/publications/osmnx-paper/"
+        )
+    else:  # pragma: no cover
+        err_msg = f"unrecognized citation style {style!r}"
+        raise ValueError(err_msg)
 
-    print(cite)
+    print(msg)  # noqa: T201
 
 
 def ts(style="datetime", template=None):
     """
-    Get current timestamp as string.
+    Return current local timestamp as a string.
 
     Parameters
     ----------
     style : string {"datetime", "date", "time"}
-        format the timestamp with this built-in template
+        format the timestamp with this built-in style
     template : string
-        if not None, format the timestamp with this template instead of one of
-        the built-in styles
+        if not None, format the timestamp with this format string instead of
+        one of the built-in styles
 
     Returns
     -------
     ts : string
-        the string timestamp
+        local timestamp string
     """
     if template is None:
         if style == "datetime":
@@ -72,10 +80,10 @@ def ts(style="datetime", template=None):
         elif style == "time":
             template = "{:%H:%M:%S}"
         else:  # pragma: no cover
-            raise ValueError(f'unrecognized timestamp style "{style}"')
+            msg = f"unrecognized timestamp style {style!r}"
+            raise ValueError(msg)
 
-    ts = template.format(dt.datetime.now())
-    return ts
+    return template.format(dt.datetime.now().astimezone())
 
 
 def config(
@@ -189,11 +197,14 @@ def config(
     -------
     None
     """
-    warnings.warn(
-        "The `utils.config` function is deprecated and will be removed in a "
-        "future release. Instead, use the `settings` module directly to "
+    warn(
+        "The `utils.config` function is deprecated and will be removed in "
+        "the v2.0.0 release. Instead, use the `settings` module directly to "
         "configure a global setting's value. For example, "
-        "`ox.settings.log_console=True`."
+        "`ox.settings.log_console=True`. "
+        "See the OSMnx v2 migration guide: https://github.com/gboeing/osmnx/issues/1123",
+        FutureWarning,
+        stacklevel=2,
     )
 
     # set each global setting to the argument value
@@ -277,21 +288,21 @@ def log(message, level=None, name=None, filename=None):
 
     # if logging to console (terminal window) is turned on
     if settings.log_console:
-        # prepend timestamp
+        # prepend timestamp then convert to ASCII for Windows command prompts
         message = f"{ts()} {message}"
+        message = ud.normalize("NFKD", message).encode("ascii", errors="replace").decode()
 
-        # convert to ascii so it doesn't break windows terminals
-        message = (
-            unicodedata.normalize("NFKD", str(message)).encode("ascii", errors="replace").decode()
-        )
-
-        # print explicitly to terminal in case jupyter notebook is the stdout
-        if getattr(sys.stdout, "_original_stdstream_copy", None) is not None:
-            # redirect captured pipe back to original
-            os.dup2(sys.stdout._original_stdstream_copy, sys.__stdout__.fileno())
-            sys.stdout._original_stdstream_copy = None
-        with redirect_stdout(sys.__stdout__):
-            print(message, file=sys.__stdout__, flush=True)
+        try:
+            # print explicitly to terminal in case Jupyter has captured stdout
+            if getattr(sys.stdout, "_original_stdstream_copy", None) is not None:
+                # redirect the Jupyter-captured pipe back to original
+                os.dup2(sys.stdout._original_stdstream_copy, sys.__stdout__.fileno())
+                sys.stdout._original_stdstream_copy = None
+            with redirect_stdout(sys.__stdout__):
+                print(message, file=sys.__stdout__, flush=True)
+        except OSError:
+            # handle pytest on Windows raising OSError from sys.__stdout__
+            print(message, flush=True)  # noqa: T201
 
 
 def _get_logger(level, name, filename):
@@ -315,7 +326,6 @@ def _get_logger(level, name, filename):
 
     # if a logger with this name is not already set up
     if not getattr(logger, "handler_set", None):
-
         # get today's date and construct a log filename
         log_filename = Path(settings.logs_folder) / f'{filename}_{ts(style="date")}.log'
 
